
romantic_messages = [
    "Hey there, love! 🌸 How's my sunshine doing today? 💕",
    "You light up my world, my dear! 🌟",
    "You're the sweetest part of my day, love. 🥰",
    "I'm so lucky to have you, my queen! 👑",
    "Every moment with you is a treasure. 💖"
]

frames = [
    """
      ❤      
    """,
    """
     💛    
    """,
    """
      💚   
    """,
    """
      💙  
    """
]

gradient_colors = ["red", "yellow", "green", "blue", "magenta", "cyan", "white"]